@@ -1,4 +1,3 @@
-import pytest
 import python_jsonschema_objects as pjo
 
 
@@ -14,11 +13,11 @@ def test_114():
                         "oneOf": [
                             {
                                 "type": "string",
-                                "pattern": "^(?:(?:\\d|[1-9]\\d|1\\d\\d|2[0-4]\\d|25[0-5])\\.){3}(?:\\d|[1-9]\\d|1\\d\\d|2[0-4]\\d|25[0-5])$",
+                                "pattern": r"^(?:(?:\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.){3}(?:\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])$",  # noqa: E501
                             },
                             {
                                 "type": "string",
-                                "pattern": "^((([0-9A-Fa-f]{1,4}:){1,6}:)|(([0-9A-Fa-f]{1,4}:){7}))([0-9A-Fa-f]{1,4})$",
+                                "pattern": r"^((([0-9A-Fa-f]{1,4}:){1,6}:)|(([0-9A-Fa-f]{1,4}:){7}))([0-9A-Fa-f]{1,4})$",  # noqa: E501
                             },
                         ]
                     }
